from norminette.rules import Rule


class CheckTernary(Rule):
    def __init__(self):
        super().__init__()
        self.depends_on = ["IsTernary"]

    def run(self, context):
        """
        Ternaries are forbidden
        """
        context.new_error("TERNARY_FBIDDEN", context.peek_token(0))
        return False, 0



from norminette.rules import Rule


class CheckLabel(Rule):
    def __init__(self):
        super().__init__()
        self.depends_on = ["IsLabel"]

    def run(self, context):
        """
        Goto and labels are forbidden
        """
        context.new_error("LABEL_FBIDDEN", context.peek_token(0))
        return False, 0



from norminette.rules import Rule


class CheckLineLen(Rule):
    def __init__(self):
        super().__init__()
        self.depends_on = []

    def run(self, context):
        """
        Lines must not be over 80 characters long
        """
        for tkn in context.tokens[: context.tkn_scope]:
            if tkn.type == "NEWLINE" and tkn.pos[1] > 81:
                context.new_error("LINE_TOO_LONG", tkn)
        return False, 0
